;; Generated package description from highlight-escape-sequences.el  -*- no-byte-compile: t -*-
(define-package "highlight-escape-sequences" "0.4.0.20171117.123748" "Highlight escape sequences" 'nil :keywords '("convenience") :authors '(("Dmitry Gutov" . "dgutov@yandex.ru") ("Pavel Matcula" . "dev.plvlml@gmail.com")) :maintainer '("Dmitry Gutov" . "dgutov@yandex.ru") :url "https://github.com/dgutov/highlight-escape-sequences")
